//
// Created by illyum on 9/15/2024.
//

#include "ICEngine.hpp"
#include "pch.hpp"

namespace ICEngine {
	ICEApplication::TerminationHandler ICEApplication::customHandler = ICEApplication::DefaultTerminationHandler;

	void ICEApplication::SetTerminationHandler(TerminationHandler handler) {
		if (handler) {
			customHandler = handler;
		} else {
			customHandler = DefaultTerminationHandler;
		}
	}

	void ICEApplication::HandleFatalError(const std::string &message) {
		if (customHandler) {
			customHandler(message);
		} else {
			DefaultTerminationHandler(message);
		}
	}

	void ICEApplication::DefaultTerminationHandler(const std::string &message) {
		Log::GetCoreLogger()->Log(CRITICAL, __FILE__, __LINE__, __FUNCTION__, message);
		std::exit(EXIT_FAILURE);
	}

	void StartApplication() {
		Log::Init();
		CORE_LOG_TRACE("Starting ICEngine");

		ICEApplication *app = CreateICEApplication();
		if (app) {
			CORE_LOG_TRACE("Starting User Application");
			app->Run();
			delete app;
		} else {
			CORE_LOG_FATAL("Could not start User Application");
		}

		CORE_LOG_TRACE("Shutting down ICEngine");
	}
}
